@@ -1,5 +1,5 @@
 package Consul::API::Agent;
-$Consul::API::Agent::VERSION = '0.019';
+$Consul::API::Agent::VERSION = '0.020';
 use namespace::autoclean;
 
 use Moo::Role;
@@ -23,7 +23,11 @@ package
 
 use Moo;
 
+use Consul::Check;
+use Consul::Service;
+
 use Carp qw(croak);
+use Scalar::Util qw( blessed );
 
 sub checks {
     my ($self, %args) = @_;
@@ -77,6 +81,10 @@ sub force_leave {
 sub check_register {
     my ($self, $check, %args) = @_;
     croak 'usage: $agent->check_register($check, [%args])' if grep { !defined } ($check);
+    {
+        local $Carp::CarpInternal{ (__PACKAGE__) } = 1;
+        $check = Consul::Check->smart_new($check) if !blessed $check;
+    }
     $$self->_api_exec($$self->_agent_endpoint."/check/register", 'PUT', %args, _content => $check->to_json);
     return;
 }
@@ -112,6 +120,7 @@ sub check_fail {
 sub service_register {
     my ($self, $service, %args) = @_;
     croak 'usage: $agent->service_register($service, [%args])' if grep { !defined } ($service);
+    $service = Consul::Service->new($service) if !blessed $service;
     $$self->_api_exec($$self->_agent_endpoint."/service/register", 'PUT', %args, _content => $service->to_json);
     return;
 }
@@ -131,7 +140,7 @@ sub service_maintenance {
 }
 
 package Consul::API::Agent::Check;
-$Consul::API::Agent::Check::VERSION = '0.019';
+$Consul::API::Agent::Check::VERSION = '0.020';
 use Moo;
 use Types::Standard qw(Str);
 
@@ -145,7 +154,7 @@ has service_id   => ( is => 'ro', isa => Str, init_arg => 'ServiceID',   require
 has service_name => ( is => 'ro', isa => Str, init_arg => 'ServiceName', required => 1 );
 
 package Consul::API::Agent::Service;
-$Consul::API::Agent::Service::VERSION = '0.019';
+$Consul::API::Agent::Service::VERSION = '0.020';
 use Moo;
 use Types::Standard qw(Str Int ArrayRef);
 
@@ -156,7 +165,7 @@ has port    => ( is => 'ro', isa => Int,           init_arg => 'Port',    requir
 has tags    => ( is => 'ro', isa => ArrayRef[Str], init_arg => 'Tags',    required => 1, coerce => sub { $_[0] || [] } );
 
 package Consul::API::Agent::Member;
-$Consul::API::Agent::Member::VERSION = '0.019';
+$Consul::API::Agent::Member::VERSION = '0.020';
 use Moo;
 use Types::Standard qw(Str Int HashRef);
 
@@ -173,7 +182,7 @@ has delegate_max => ( is => 'ro', isa => Int,          init_arg => 'DelegateMax'
 has delegate_cur => ( is => 'ro', isa => Int,          init_arg => 'DelegateCur', required => 1 );
 
 package Consul::API::Agent::Self;
-$Consul::API::Agent::Self::VERSION = '0.019';
+$Consul::API::Agent::Self::VERSION = '0.020';
 use Moo;
 use Types::Standard qw(HashRef);
 use Type::Utils qw(class_type);
